import pytest

from numerous_report_generator.report import Report

def uploader(filename, file_id):
    pass

def test_create_report():
    report = Report(uploader)